clc; clear all; close all

%% Clculo de costes e ingresos evaporador de 3 efectos

load('1_efec.mat')

%% Costes del equipo

%Evaporador
a = 330;
b = 36000; % coeficientes para evaporadores "Chemical Engineering Design Principles, Practice and Economics of Plant and Process Design" 
n = 0.55;

C_evap = NEF*(a+b*A^n); % $ Coste de los NEF evaporadores en base a 2010 y en acero al carbono

%Condensador

ac = 28000;
bc = 54;
nc = 1.2;

C_cond = (ac+bc*Ac^nc);

%% Factores para calcular el coste de la instalacin
%tomados del "Chemical Engineering Design Principles, Practice and Economics of Plant and Process Design" 
fp = 0.8; %factor de instalacin de tuberas
fer = 0.3; %factor de instalacin y montaje de equipos
fi = 0.3; %factor de instalacin de instrumentacin y control del proceso
fel = 0.2; %factor de instalacin de trabajos electricos
fc = 0.3; %factor de instalacin de obras de ingeniera civil
fs = 0.2; %factor de instalacin para estructuras y edificios
fl = 0.1; %factor de instalacin para revestimientos, aislamientos o pintura
fm = 1.3; %factor de correccin del material a 316 stainless steel

%% Coste de inversin inicial CAPEX

C = (C_evap+C_cond)*((1+fp)*fm+(fer+fel+fs+fc+fi+fl)); %Coste total de la instalacin en base a 2010
% fCIA = 0.3; %factor de inversiones adicionales (costes externos)
% fCIC = 0.3; %factor de costes de ingeniera y construccin
% fCcon = 0.1; % gastos de contingencia

% CIA = C*fCIA; % $ inversiones adicionales
% CIC = (C+CIA)*fCIC; % $ costes de ingeniera y construccin
% Ccon = (C+CIA)*fCcon; % $ gastos de contingencia
% Cfijo = C+CIA+CIC+Ccon; % $ capital fijo total
% CAC = 0.1*Cfijo; % $ capital circulante
C2010 = C; % $ CAPEX en base a enero de 2010 en dlares EU

CEPCI2010 = 532.9;
CEPCI2018 = 603.1;
C2018 = C2010*CEPCI2018/CEPCI2010; % CAPEX actualizado a 2018 en dlares EU
tasa = 0.88; % /$ tasa de cambio 
CAPEX = C2018*tasa; %  inversin de capital necesaria total

%% Ingresos

% p_zumo_conc = 60; % $/Kg precio de venta del zumo a 65 Brix
% I = L(end)*p_zumo_conc*120*24*3600*tasa; % /ao
%% Costes de operacin

%% Costes fijos

%Mano de obra
%Se suponen 3 posiciones de cambio, a 4.8 operadores por posicin segn el
%libro "Chemical Engineering Design Principles, Practice and Economics of Plant and Process Design"
% Salario de 50000 $/aoposicin de cambio
% SP = 3;
% Op = 4.8*SP; % nmero total de operadores al ao 3 posiciones de cambio
% Sal = 120*50000*SP/365; % $/ao salario total al ao sin contar supervision ni seguros y teniendo en cuenta que se trabajan 120 das
% superv = 0.25*Sal; % $/ao gastos de supervisin 25% del coste del salario
% over = 0.6*(Sal+superv); % $/ao salary overhead 60% del coste del salario+supervisin
% 
% CMO = tasa*(Sal+superv+over); %/ao
% 
% %Mantenimiento
% CM = 0.03*C*tasa; % /ao
% 
% %Costes alquiler, seguros e impuestos
% CASI = 0.01*(C+CIA)*tasa; %/ao
% 
% % Costes I+D
% CID = 0.01*I; % /ao el factor es 1% porque la tecnologa de evaporacin 
%               %ha sido objeto de varios estudios
% 
% % Gastos generales y de administracin
% CG = 0.65*I; %/ao

%Amortizacin (Datos sacados de la agencia tributaria)
ny = 20; %nmero de aos para amortizar
i = 0.1; % inters anual del dinero
CRF = ((1+i)^ny-1)/(i*(1+i)^ny); %factor de recuperacin de capital
amort = CAPEX/CRF; % /ao amortizacin anual a pagar
%% Costes variables

%Coste materia prima
p_zumo_dil = 1.33; % $/Kg de granadas
CMP = tasa*3*p_zumo_dil*F*120*24*3600/dens; % /ao coste de la alimentacin (3 Kg de granadas = 1 litro de zumo diluido)


% Coste vapor saturado (Cs,u=a*CEPCI2018+b*Cs,f)
% P = 1.2; % presin del vapor requerido en bar
% a = (2.7*10^-5)*S^-0.9;
% b = 0.0034*P^0.05; % a y b coeficientes para utilities del estudio de Gael D-Ulrich y P T. Vasudevan
% Csf_vapor = 12; % $/GJ Precio del combustible

Cs_vapor = 0.1; % $/kg Precio del vapor saturado de acuerdo a www.intratec.us
Cs_vapor_anual = Cs_vapor*S*120*3600*24*tasa; % /ao coste del vapor saturado anual

%Coste agua de refrigeracin en el condensador
% q = ma; %m3/s flujo de agua requerido
% a = 0.0001+0.00003*q^-1; b = 0.003; % Coeficientes para calcular utilities
% Csf_agua = 0.69*50; %  $/GJ Precio del combustible 0.69 es la tasa de cambio de dolar australiano a dolar eeuu
Cs_agua = 0.15; %$/m3 Precio del agua de refrigeracin de acuerdo a www.intratec.us
Cs_agua_anual = Cs_agua*ma*120*3600*24*tasa; % /ao coste del agua anual

%% Coste fijo total
CF = amort;

%% Coste variable total
CV = Cs_vapor_anual+Cs_agua_anual;

%% Coste total anual

C_total = CF+CV; %

%% Balance costes ingresos

% Balanc = I - C_total;

%% Salida resultados

fprintf('Coste anual= %.1f () \n',C_total);


save('1_efec_cost','CF','CV','C_total')
