clc
clear all
close all

%% Script de diseo intercambiador 3 efectos
% Se toma el tercer efecto para el diseo porque es el que mayor tasa de vaporizacin
% presenta

funciones

%% Datos
Dext_tubo = 0.045; %Diametro exterior en tubos
e_tubo = 0.00122; % espesor del tubo en m
L_tubo = 1; %longitud tubo en m
e_estruc_tubos = 0.032; % m espesor estructura tubos
expan_tubo = 0.005; %expansion del tubo en m
legment = 0.01; % m material entre dos agujeros de tubo
tube_clearance = 0.0003; % m
estruc_tubos_clearance = 0.0001; % m
beta = 0.9; %factor proporcional
p_D_estruc_tubos_toma = 20; % porcentaje del diametro de la toma del tubo respecto al area de la estructura de tubos
vol_esp_entr = 3.372; % m3/Kg volumen especfico del vapor de entrada
vol_esp_sal = 19.55; % m3/Kg volumen especfico del vapor de salida
v_vapor_entr = 40; % m/s velocidad vapor entrada
v_vapor_sal = 50; % m/s velocidad vapor salida
v_conds = 0.6; % m/s velocidad del condensado
water_dens = 1000; %Kg/m3

% Se carga el archivo con los datos calculados del evaporador de 3 efectos
load('3_efec.mat')
TV_entr = TV(2)-273; % C temperatura del vapor de entrada 
TV_sal = TV(3)-273; % C temperatura del vapor de salida
V_rat = V(3)*3600/A; % Kg/m2*h ratio de evaporacin

%% 1. Nmero de tubos

Dm = Dext_tubo-e_tubo; % m dimetro medio del tubo
Le = L_tubo-2*e_estruc_tubos-2*expan_tubo; % m longitud efectiva del tubo
ntubos=A/(pi*Dm*Le);
ntubos = 40; % redondeo
%% 2. Estructura de tubos y dimetro de la toma

%Carcasa
paso_tubo = Dext_tubo+legment+tube_clearance+estruc_tubos_clearance; % m paso del tubo
extra = 1.2; % porcentaje de diametro extra en caso de multiples tomas
area_tubos = (0.866*(paso_tubo)^2*ntubos/beta)*extra; %m2 rea requerida solo para los tubos
D_estruc_tubos= sqrt(area_tubos*4/pi); % m dimetro de la carcasa requerido para los tubos

% En caso de una sola toma
D_toma=D_estruc_tubos*p_D_estruc_tubos_toma/100; % m dimetro de la toma
area_toma = pi*D_toma^2/4; % m2 rea de la toma
area_total= area_tubos+area_toma; %m2 rea total sumando la de la toma
D_final_estruc_tubos=sqrt(area_total*4/pi); % m dimetro de la estructura de tubos
D_final_estruc_tubos= 0.440; % m normalizacin

%En caso de multiples tomas
D_tomas_perif= 0.011; % m dimetro de las tomas perifricas
n_tomas = 8; %nmero de tomas perifricas
area_total_tomas = n_tomas*pi*D_tomas_perif^2/4; % m2 rea que ocupan las tomas perifricas
area_central= area_toma-area_total_tomas; % m2 rea disponible para la toma central
D_toma_central = sqrt(area_central*4/pi); % m dimetro de la toma central

%% 3. Dimetro para la entrada de vapor y dimetro de la calandria

%Entrada de vapor
V_vapor = V(3)*3600; % Kg/h Vapor requerido en la calandria 
caudal = V_vapor*vol_esp_entr/3600; % m3/s caudal volumtrico
A_entr_vapor = caudal/v_vapor_entr; % m2 rea de la entrada de vapor
D_entr_vapor = sqrt(A_entr_vapor*4/pi); % m dimetro de la entrada de vapor
D_entr_vapor = 0.1; %m nominalizacin

%Dimetro de la calandria en la zona de la entrada de vapor
A_entr_vapor = pi*D_entr_vapor^2/4; % m2 nueva rea de la entrada tras la nominalizacin
h_entr_vapor = Le;
a_entr_vapor = A_entr_vapor/h_entr_vapor; % m anchura entrada de vapor
D_calandria_entr_vapor = D_final_estruc_tubos+a_entr_vapor;

%% 4. Dimetro de la salida de vapor

caudal_sal_vapor = A*V_rat*vol_esp_sal/3600; %m3/s caudal volumtrico de vapor de salida
D_sal_vapor = sqrt(caudal_sal_vapor/(0.785*v_vapor_sal)); % m dimetro salida de vapor
D_sal_vapor = 0.2; % m normalizacin

%% 5. Dimetro de la lnea de condensado

V_conds = A*V_rat; % Kg/h flujo de condensado
caudal_conds = 1.1*V_conds/(water_dens*3600); %m3/s caudal condensado
nconds = 1; %lneas de condensado
D_conds = sqrt(caudal_conds/(0.785*v_conds))/nconds; % m dimetro tubera condensado
D_conds = 0.05; % m normalizacin

%%  6. Gases nocivos

A_no_conds_gas = A/10/10000; % m2 rea transversal de los gases no condensables
nsalidas = 1 ; %nmero de salidas
D_no_conds_gas = sqrt(4*A_no_conds_gas/(3.14*nsalidas)); % m
D_no_conds_gas = 0.025; % m normalizacin

%% 7. Altura del espacio de vapor

h_factor = 2; %factor para multiplicar por la longitud de los tubos
V_altura = L_tubo*h_factor; % m altura del espacio de vapor

%% 8. Velocidad en el espacio de vapor

caudal_espac_vapor = A*V_rat*vol_esp_sal/3600; % m3/s caudal de vapor
A_transv = 0.15; % m2 rea transversal
v_espac_vapor = caudal_espac_vapor/A_transv; % m/s velocidad del vapor en el espacio de vapor

%% 9. Espesor de la carcasa de la calandria

P_calandria = 3; % Kg/cm2 mxima presin soportable
Dint_calandria = D_final_estruc_tubos-2*e_estruc_tubos; % m dimetro interior de la calandria
F_calandria = 1400; % Kg/cm2 estrs soportable
J_calandria = 0.7; % eficiencia de las juntas
C_calandria = 0.0015; % m permisividad a la corrosin

e_calandria = (P_calandria*Dint_calandria/(2*F_calandria*J_calandria-P_calandria))+C_calandria; % m espesos de la calandria
e_calandria = 0.004; % m normalizacin

%% 10. Espesor de la carcasa de vapor

P_carcasa_vapor = 2; % Kg/cm2 mxima presin soportable
Dint_carcasa_vapor = Dint_calandria; % m dimetro interior de la calandria
F_carcasa_vapor = 1400; % Kg/cm2 estrs soportable
J_carcasa_vapor = 0.7; % eficiencia de las juntas
C_carcasa_vapor = 0.0015; % m permisividad a la corrosin

e_carcasa_vapor = (P_carcasa_vapor*Dint_carcasa_vapor/(2*F_carcasa_vapor*J_carcasa_vapor-P_carcasa_vapor))+C_carcasa_vapor; % m espesos de la calandria
e_carcasa_vapor = 0.002; % m normalizacin

%% 11. Espesor de la placa de tubos
P_placa_tubos = 2.72; % Kg/cm2 mxima presin soportable
C_placa_tubos = 0.0015; % m permisividad a la corrosin
F_placa_tubos = 1400; % Kg/cm2 estrs soportable
Es = 2100000; % Kg/cm2 Modulus factor for MS sheet
Et = 1900000; % Kg/cm2 Modulus factor for SS sheet
G = Dint_calandria; % m
ts = e_calandria; % m
tt = e_tubo; % m
d0 = Dext_tubo; % m
D0 = D_final_estruc_tubos; % m Dimetro del cuerpo
Nt = ntubos;
K = (Es*ts*(D0-ts))/(Nt*Et*tt*(d0-tt));
f = sqrt(K/(2+3*K)); % factor de seguridad
e_carcasa_tubos = f*G*sqrt((0.25*P_placa_tubos)/F_placa_tubos)+C_placa_tubos; % m espesor de la carcasa de tubos

%% 12. Dimetro de la zona cnica superior (cpula vapor)
factor_vapor_cupula = 2;
A_vapor_cupula = factor_vapor_cupula*(pi*D_sal_vapor^2/4); % m2 seccin de la cpula de vapor
D_vapor_cupula = sqrt(A_vapor_cupula*4/pi); % m Dmetro de la seccin de la cpula de vapor
D_vapor_cupula = 0.3; % m normalizacin

%% 13. Altura del cono superior
angulo_cono = 30; % deg ngulo de la aparte superior del intercambiador
h_cono = tan(angulo_cono*pi/180)*((D0-D_vapor_cupula)/2); % m altura de la zona cono de la parte superior del evaporador

%% 14. rea de la zona central (umbrella)

% Caso 1
A_umbrella_1 = (pi*D0^2/4)-A_vapor_cupula; % m2
D_umbrella_1 = sqrt(A_umbrella_1*4/pi); % m dimetro de la zona central

%Caso 2
D_umbrella_2 = 0.6*D0; % m dimetro de la zona central

% Tomamos el Caso 2
h_umbrella_cono_entr = A_vapor_cupula/(pi*D_umbrella_2); % m espaciado entre la umbrella y la entrada de vapor
h_umbrella_cono_sal = A_vapor_cupula/(pi*D_vapor_cupula); % m espaciado entre la umbrella y la salida de vapor

%% Dimensiones de acuerdo al dibujo del evaporador de sugarprocesstech

D1 = D0; % m dimetro del cuerpo
H1 = L_tubo; % m longitud tubos
H2 = 2*H1; % m altura desde la calandria hasta el principio del cono superior
H3 = h_cono; % m altura del cono de la parte superior
D3 = D_vapor_cupula; % m dimetro parte superior del evaporador
H4 = D3; % m altura de la parte superior del evaporador despus del cono
D2 = 0.2*D1; % m separacin entre los compartimentos de tubos
D4 = D_sal_vapor; % m dimetro de la tubera de entrada de vapor
D5 = 0.25*D1; % m dimetro de la parte inferior del evaporador
H5 = tan(20*pi/180)*((D1-D5)/2); % m altura del cono inferior del evaporador
sep = 0.15; % m separacin entre el compartimento de tubos y el cono inferior

H_total = H1+H2+H3+H4+H5+sep % m altura total del evaporador
D_evaporador = D0 % m dimetro principal del evaporador
%% Tiempo de residencia

y = V(3)/L(2); % fraccin msica de vapor en relacin a la alimentacin
RL = 1-(1/(1+((1-y)/y)*(2*dens_vapor(TV(2))/dens)^5)); % fraccin de lquido en el evaporador

t = RL*(pi*D0^2/4)*L_tubo/(L(3)/(dens)) % segundos tiempo de residencia del lquido en el intercambiador
volumen_liquido = (L(3)/(dens))*t % m3 volumen ocupado por el lquido